# OS 프로젝트

## 중간 프로젝트

[프로젝트 과제 목록](./contents/index.md)에 있는 프로젝트 중 하나를 선택하세요. 프로젝트에 대한 요구 사항을 주의 깊게 읽고 이해한 후 프로젝트 개요와 진행계획을 작성하세요. 작성결과를 본인의 프로젝트 디렉토리의 `index.md` 파일에 반영하세요.

프로젝트와 별개로 매주차 `Homework: 제목` 형식으로 제공되는 과제도 수행하세요. 과제 제출은 과제에 별도로 명시된 방법으로 따르세요. 제출기한은 각 과제별로 별도로 명시됩니다.

**과제 목록:**

- [Homework: 프로세스](../week02/hw-wk02.md)
- [Homework: 스케줄링](../week03/hw-wk03.md)
- [Homework: 비례 배분](../week04/hw-wk04.md)
- [Homework: 주소 변환의 원리](../week06/hw-wk06.md)
- [Homework: 빈 공간 관리](../week07/hw-wk07.md)

## 기말 프로젝트

중간 프로젝트에서 선택한 프로젝트를 완성하세요. 프로젝트를 완료한 후 프로젝트 결과와 개선 방향을 작성하세요. 작성결과를 본인의 프로젝트 디렉토리의 `index.md` 파일에 반영하세요.

프로젝트 코드와 결과를 포함한 프로젝트 디렉토리를 본인의 프로젝트 디렉토리에 추가하세요.

```{tableofcontents}

```
